import React from 'react'
import { Button, Form, Input, Select } from 'antd'
import ImageUpload from '@/components/XForm/ImageUpload'
import ModalForm from '../components/ModalForm'
import InputNumber from '../components/InputNumber'
import { validMinNum } from '../utils'

const Option = Select.Option
const fullWidth = { width: '100%' }

const AMForm = (props) => {
  const { visible, onCancel, form } = props
  const { getFieldDecorator } = form

  return (
    <ModalForm
      title="户型设置"
      visible={visible}
      onCancel={onCancel}
    >
      <Form.Item label="编号" style={{ display: 'none' }}>
          {getFieldDecorator('apartmentId')(<Input />)}
      </Form.Item>
      <Form.Item label="户型名称">
        {getFieldDecorator('apartmentName', {
          rules: [
            { required: true, message: '请填写户型名称' },
            { max: 10, message: '户型名称不超过10个字符' },
          ],
        })(<Input placeholder="户型名称不超过10个字符"/>)}
      </Form.Item>
      <Form.Item label="销售状态">
        {getFieldDecorator('marketStatus', {
          rules: [{ required: true, message: '请选择销售状态' }],
        })(
          <Select placeholder="销售状态">
            <Option value="未开盘">未开盘</Option>
            <Option value="在售">在售</Option>
            <Option value="售罄">售罄</Option>
          </Select>
        )}
      </Form.Item>
      <Form.Item label="图片" help="建议图片尺寸336px*336px，比例1:1,格式：jpg">
      {getFieldDecorator('img', {
          rules: [{ required: true, message: '请上传户型图片' }],
      })(
        <ImageUpload />,
      )}
      </Form.Item>
      <Form.Item label="厅室">
        {getFieldDecorator('houseType', {
          rules: [{ required: true, message: '请填写户型厅室' }],
        })(<Input placeholder="例如: 三室一厅" />)}
      </Form.Item>
      <Form.Item label="面积">
        {getFieldDecorator('buildingArea', {
            rules: [{ validator: validMinNum }]
          })(<InputNumber precision={2} min={0} step={0.01} addonAfter="㎡" />)}
      </Form.Item>
      <Form.Item label="使用面积">
        {getFieldDecorator('insideArea', {
            rules: [{ validator: validMinNum }]
          })(<InputNumber precision={2} min={0} step={0.01} addonAfter="㎡" />)}
      </Form.Item>
      <Form.Item label="权重" help="数值越大越靠前">
        {getFieldDecorator('orderNo', {
            rules: [{ validator: validMinNum }]
          })(<InputNumber min={0} step={1} style={fullWidth} />)}
      </Form.Item>
      <Form.Item label=" " colon={false} style={{marginTop: '2em'}}>
        <Button style={{marginLeft: '4em'}} type="primary" htmlType="submit">保存</Button>
        <Button style={{marginLeft: '2em'}} onClick={props.onCancel}>取消</Button>
      </Form.Item>
    </ModalForm>
  )
}

export default Form.create({})(AMForm)
