import React from 'react'
import { Button, Form, Input, DatePicker } from 'antd'
import ModalForm from '../components/ModalForm'
import InputNumber from '../components/InputNumber'
import { validMinNum } from '../utils'

const fullWidth = { width: '100%' }

const AMForm = (props) => {
  const { visible, onCancel, form } = props
  const { getFieldDecorator } = form

  return (
    <ModalForm
      title="特价房设置"
      visible={visible}
      onCancel={onCancel}
    >
      <Form.Item label="房源">
        {getFieldDecorator('apartmentName', {
          rules: [
            { required: true, message: '请填写房源' },
            { max: 30, message: '房源不超过30个字符' },
          ],
        })(<Input placeholder="比如 3# 15-02"/>)}
      </Form.Item>
      <Form.Item label="户型">
        {getFieldDecorator('apartmentName', {
          rules: [
            { required: true, message: '请填写房源' },
            { max: 30, message: '房源不超过30个字符' },
          ],
        })(<Input placeholder="比如 三室一厅"/>)}
      </Form.Item>
      <Form.Item label="面积">
        {getFieldDecorator('apartmentName', {
          rules: [
            { required: true, message: '请填写面积' },
            { validator: validMinNum },
          ],
        })(<InputNumber min={0} precision={0.01} step={1} addonAfter="㎡"/>)}
      </Form.Item>
      <Form.Item label="时间">
      {getFieldDecorator('img', {
          rules: [{ required: true, message: '请选择时间' }],
      })(
        <DatePicker.RangePicker
          showTime={{ format: 'HH:mm' }}
          format="YYYY-MM-DD HH:mm"
          placeholder={['开始时间', '结束时间']}
          style={fullWidth} />,
      )}
      </Form.Item>
      <Form.Item label="原始价">
        {getFieldDecorator('apartmentName', {
          rules: [
            { required: true, message: '请填写原始价' },
          ],
        })(<Input placeholder="请填写原始价"/>)}
      </Form.Item>
      <Form.Item label="现价">
        {getFieldDecorator('apartmentName', {
          rules: [
            { required: true, message: '请填写现价' },
          ],
        })(<Input placeholder="请填写现价"/>)}
      </Form.Item>
      <Form.Item label="节省价">
        {getFieldDecorator('apartmentName', {
          rules: [
            { required: true, message: '请填写节省价' },
          ],
        })(<Input placeholder="请填写节省价"/>)}
      </Form.Item>
      <Form.Item label=" " colon={false} style={{marginTop: '2em'}}>
        <Button style={{marginLeft: '4em'}} type="primary" htmlType="submit">保存</Button>
        <Button style={{marginLeft: '2em'}} onClick={props.onCancel}>取消</Button>
      </Form.Item>
    </ModalForm>
  )
}

export default Form.create({})(AMForm)
