import React, { useEffect, useState } from 'react';

import { message} from 'antd';
import apis from '@/services/apis';
import router from 'umi/router';
import XForm, { FieldTypes } from '@/components/XForm';
import Wangedit from '@/components/Wangedit/Wangedit';
import request from '@/utils/request';
import searchFields from '@/pages/building/Developers/searchFields';
import QueryTable from '@/components/QueryTable'
import BuildSelect from '@/components/SelectButton/BuildSelectHouse';



const Basic = props => {
  const { newsId } = props;
  const [dynamicData, setDynamicData] = useState({});
  const [changeBuildingId, setChangeBuildingIdData] = useState('');
  const [newsDetailType, setNewsDetailType] = useState(1);

  useEffect(() => {
    if (newsId) {
      getDynamicData(newsId);
    }
  }, [newsId]);

  // 查询详情
  const getDynamicData = newsId => {
    request({ ...apis.news.get, urlData: { id: newsId } })
      .then(data => {
        setDynamicData(data);
        console.log(data, 'sss');
        setNewsDetailType(Number(data.newsDetailType));
      })
      .catch(err => {
        console.log(err);
        message.info(err.msg || err.message);
      });
  };

  const handleBuildingChange = e => {
    console.log(e);
    setChangeBuildingIdData(e);
  };


  const fields = [


    // {
    //   label: '城市',
    //   name: 'building',
    //   option:[
    //     {label:'南京',value:'1'},
    //     {label:'北京',value:'2'},
    //   ]
    // },
    {
      label: '意向项目',
      name: 'buildingId',
      render: <BuildSelect  />,
      // onChange={e => handleBuildingChange(e)}
      // value: dynamicData.buildingId,
      rules: [{ required: true, message: '请选择所属项目' }],
    },
    {
      label: '类型',
      name: 'typesId',
      value: dynamicData.buildingId,
      option:[
        {label:'买房准备',value:'1'},
        {label:'看房选房',value:'2'},
        {label:'认筹签约',value:'3'},
      ]
    },
    {
      label: '购房百科封面图',
      name: 'newsImg',
      type: FieldTypes.ImageUploader,
      value: dynamicData.newsImg,
      help: '建议尺寸：220px*176px，比例5:4，格式：jpg，用于：购房百科列表',
      rules: [{ required: true, message: '请选择购房百科封面图' }],
    },
    {
      label: '政策标题',
      name: 'newsName',
      type: FieldTypes.Text,
      value: dynamicData.newsName,
      rules: [{ required: true, message: '请输入政策标题' }],
    },

    {
      label: '政策详情',
      name: 'newsDetail',
      render: <Wangedit />,
      hidden: newsDetailType == 0,
      value: dynamicData.newsDetail,
      rules: [{ required: true, message: '请输入政策详情' }],
    },
      {
      label: '状态',
      name: 'newsTypeId',
      option:[
        {label:'已发布',value:'1'},
        {label:'未发布',value:'2'},
      ]
    },
  ];

  // const handleSubmit = val => {
  //   console.log(dynamicData, '12312345');
  //   let { ...submitValue } = val;

  //   if (newsId) {
  //     submitValue.newsId = newsId;
  //     request({ ...apis.news.put, urlData: { id: newsId }, data: { ...submitValue } })
  //       .then(data => {
  //         // cancelPage();
  //         message.info('保存成功');
  //         console.log(data, 'data1');
  //       })
  //       .catch(err => {
  //         message.info(err.msg || err.message);
  //       });
  //   } else {
  //     request({ ...apis.news.post, data: { ...submitValue } })
  //       .then(data => {
  //         // cancelPage();
  //         message.info('保存成功');
  //         router.go(-1);
  //         console.log(data, 'data2');
  //       })
  //       .catch(err => {
  //         message.info(err.msg || err.message);
  //       });
  //   }
  // };

  const cancelPage = () => {
    router.go(-1);
  };

  return <XForm  onCancel={cancelPage} searchFields={searchFields} fields={fields}></XForm>;
  // onSubmit={handleSubmit}
  
};

export default Basic;