
import React, { useState, useEffect } from 'react';
import { Button, message, Table, Modal, Card } from 'antd';
import withActions from '@/components/ActionList';
import EditIcon from '@/components/EditIcon';
import router from 'umi/router';
import request from '@/utils/request'
import apis from '@/services/apis';
import AuthButton from '@/components/AuthButton';


const header = props => {
  function addRole(roleId) {
    router.push({
      pathname: '/system/Sellhouse/houseTypes/Newindex',
    });
  }
  function stop(ids, status) {
    Modal.confirm({
      title: "确认要删除此条内容吗",
      okText: '确认',
      cancelText: '取消',
      onOk() {
        request({ ...apis.role.stop, urlData: { id: ids } }).then((data) => {
          getRoleList({ pageNum: 1, pageSize: 100 })
        }).catch((err) => {
          console.log(err)
          message.info(err.msg || err.message)
        })
      }
    });
  }

  const columns = [
    // {
    //   title: '商品图片',
    //   dataIndex: 'img',
    //   key: 'img',
    //   align: 'center',

    //   render: (text, record) => <img src={record.img} className={channels.touxiang} />,
    // },
    {
      title: '类型名称',
      dataIndex: 'roleName',
      key: 'roleName',
      align: 'center',

    },

    {
      title: '操作  ',
      dataIndex: 'status',
      key: 'status',
      align: 'center',

      render: withActions((text, record) => {
        return record.isAdmin ? [] :
          [
            record.status === 1 ?
            <AuthButton name="admin.role.publish" noRight={null}>
              <EditIcon type="delete" text="删除" onClick={() => stop(record.roleId, record.status)} />
            </AuthButton> : null,

            <AuthButton name="admin.role.put" noRight={null}>
              <EditIcon text="编辑" type="edit" onClick={() => toEditRole(record.roleId)} />
            </AuthButton>,
          ]
      }),
    },
  ];


  return (
    <Card>
      <AuthButton name="admin.role.add" noRight={null}>
        <Button type="primary"  onClick={addRole}>新增</Button>
      </AuthButton>
      <div style={{marginTop:'20px'}}>
        <Table rowKey="roleList"  columns={columns} />
      </div>
    </Card>

  )
}
export default header
